==> open-cluster-management-apps-model-6.1.0-sources.jar: io/fabric8/openclustermanagement/api/model/multicloudoperatorssubscription/apps/v1/PackageFilterFluent.java <==
package io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.v1;

import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.LabelSelector;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.model.LocalObjectReference;
import io.fabric8.kubernetes.api.model.LabelSelectorFluent;
import java.lang.Boolean;
import java.util.Map;
import io.fabric8.kubernetes.api.model.LocalObjectReferenceFluent;

 /**
  * Generated
  */
public interface PackageFilterFluent<A extends PackageFilterFluent<A>> extends Fluent<A>{
  public A addToAnnotations(String key,String value);
  public A addToAnnotations(Map<String,String> map);
  public A removeFromAnnotations(String key);
  public A removeFromAnnotations(Map<String,String> map);
  public Map<String,String> getAnnotations();
  public <K,V>A withAnnotations(Map<String,String> annotations);
  public Boolean hasAnnotations();
  
  /**
   * This method has been deprecated, please use method buildFilterRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public LocalObjectReference getFilterRef();
  public LocalObjectReference buildFilterRef();
  public A withFilterRef(LocalObjectReference filterRef);
  public Boolean hasFilterRef();
  public A withNewFilterRef(String name);
  public PackageFilterFluent.FilterRefNested<A> withNewFilterRef();
  public PackageFilterFluent.FilterRefNested<A> withNewFilterRefLike(LocalObjectReference item);
  public PackageFilterFluent.FilterRefNested<A> editFilterRef();
  public PackageFilterFluent.FilterRefNested<A> editOrNewFilterRef();
  public PackageFilterFluent.FilterRefNested<A> editOrNewFilterRefLike(LocalObjectReference item);
  
  /**
   * This method has been deprecated, please use method buildLabelSelector instead.
   * @return The buildable object.
   */
  @Deprecated
  public LabelSelector getLabelSelector();
  public LabelSelector buildLabelSelector();
  public A withLabelSelector(LabelSelector labelSelector);
  public Boolean hasLabelSelector();
  public PackageFilterFluent.LabelSelectorNested<A> withNewLabelSelector();
  public PackageFilterFluent.LabelSelectorNested<A> withNewLabelSelectorLike(LabelSelector item);
  public PackageFilterFluent.LabelSelectorNested<A> editLabelSelector();
  public PackageFilterFluent.LabelSelectorNested<A> editOrNewLabelSelector();
  public PackageFilterFluent.LabelSelectorNested<A> editOrNewLabelSelectorLike(LabelSelector item);
  public String getVersion();
  public A withVersion(String version);
  public Boolean hasVersion();
  public interface FilterRefNested<N> extends Nested<N>,LocalObjectReferenceFluent<PackageFilterFluent.FilterRefNested<N>>{
    public N and();
    public N endFilterRef();
    
  }
  public interface LabelSelectorNested<N> extends Nested<N>,LabelSelectorFluent<PackageFilterFluent.LabelSelectorNested<N>>{
    public N and();
    public N endLabelSelector();
    
  }
  
}

==> open-cluster-management-apps-model-6.7.0-sources.jar: io/fabric8/openclustermanagement/api/model/multicloudoperatorssubscription/apps/v1/PackageFilterFluent.java <==
package io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.v1;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.LabelSelector;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.model.LocalObjectReference;
import io.fabric8.kubernetes.api.model.LabelSelectorFluent;
import java.lang.Boolean;
import java.util.Map;
import io.fabric8.kubernetes.api.model.LocalObjectReferenceFluent;

 /**
  * Generated
  */
public interface PackageFilterFluent<A extends PackageFilterFluent<A>> extends Fluent<A>{
  public A addToAnnotations(String key,String value);
  public A addToAnnotations(Map<String,String> map);
  public A removeFromAnnotations(String key);
  public A removeFromAnnotations(Map<String,String> map);
  public Map<String,String> getAnnotations();
  public <K,V>A withAnnotations(Map<String,String> annotations);
  public Boolean hasAnnotations();
  
  /**
   * This method has been deprecated, please use method buildFilterRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public LocalObjectReference getFilterRef();
  public LocalObjectReference buildFilterRef();
  public A withFilterRef(LocalObjectReference filterRef);
  public Boolean hasFilterRef();
  public A withNewFilterRef(String name);
  public PackageFilterFluent.FilterRefNested<A> withNewFilterRef();
  public PackageFilterFluent.FilterRefNested<A> withNewFilterRefLike(LocalObjectReference item);
  public PackageFilterFluent.FilterRefNested<A> editFilterRef();
  public PackageFilterFluent.FilterRefNested<A> editOrNewFilterRef();
  public PackageFilterFluent.FilterRefNested<A> editOrNewFilterRefLike(LocalObjectReference item);
  
  /**
   * This method has been deprecated, please use method buildLabelSelector instead.
   * @return The buildable object.
   */
  @Deprecated
  public LabelSelector getLabelSelector();
  public LabelSelector buildLabelSelector();
  public A withLabelSelector(LabelSelector labelSelector);
  public Boolean hasLabelSelector();
  public PackageFilterFluent.LabelSelectorNested<A> withNewLabelSelector();
  public PackageFilterFluent.LabelSelectorNested<A> withNewLabelSelectorLike(LabelSelector item);
  public PackageFilterFluent.LabelSelectorNested<A> editLabelSelector();
  public PackageFilterFluent.LabelSelectorNested<A> editOrNewLabelSelector();
  public PackageFilterFluent.LabelSelectorNested<A> editOrNewLabelSelectorLike(LabelSelector item);
  public String getVersion();
  public A withVersion(String version);
  public Boolean hasVersion();
  public interface FilterRefNested<N> extends Nested<N>,LocalObjectReferenceFluent<PackageFilterFluent.FilterRefNested<N>>{
    public N and();
    public N endFilterRef();
    
  }
  public interface LabelSelectorNested<N> extends Nested<N>,LabelSelectorFluent<PackageFilterFluent.LabelSelectorNested<N>>{
    public N and();
    public N endLabelSelector();
    
  }
  
}
